# pycarta

PyCarta provides a pythonic interface to the Carta data virtualization and
analysis environment.

## Description

Carta provides a data virtualization environment that allows many, possibly
disparate, data resources to be connected to a uniform data processing and
analysis platform.

PyCarta provides a pythonic interface to the Carta API, allowing interactive
development of data analysis pipelines within python and development of Carta
Operations within python.
